/**
 * @file boot_common.h
 * @brief CycloneBOOT Bootloader common functions
 *
 * @section License
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * Copyright (C) 2010-2022 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneBOOT Open.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.0.2
 **/

#ifndef _BOOT_COMMON_H
#define _BOOT_COMMON_H

//Dependencies
#include "core/slot.h"
#include "core/image.h"
#include "bootloader/boot.h"
#include "error.h"

//Initialization vector size of encrypted images in external flash memory
#define INIT_VECT_SIZE 16

//CycloneBOOT Bootloader common related functions
error_t bootInitPrimaryFlash(BootContext *context, BootSettings *settings);
error_t bootInitSecondaryFlash(BootContext *context, BootSettings *settings);
error_t bootSelectUpdateImageSlot(BootContext *context, SlotDesc **selectedSlot);
error_t bootUpdateApp(BootContext *context, SlotDesc *slot);
error_t bootCheckImage(SlotDesc *slot);
error_t bootGetSlotImgHeader(SlotDesc *slot, ImageHeader *header);
error_t bootCheckSlotAppResetVector(SlotDesc *slot);

#endif //!_BOOT_COMMON_H
