/**
 * @file flash_driver_template.c
 * @brief CycloneBOOT Flash Driver Template
 *
 * @section License
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * Copyright (C) 2010-2022 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneBOOT Open.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.0.2
 **/

//Switch to the appropriate trace level
#define TRACE_LEVEL IAP_TRACE_LEVEL

//Dependencies
#include "drivers/flash/flash.h"
#include "drivers/flash/flash_driver_template.h"
#include "debug.h"


//Flash driver private related functions
error_t flashDriverInit(void);
error_t flashDriverGetInfo(const FlashInfo *info);
error_t flashDriverGetStatus(FlashStatus *status);
error_t flashDriverWrite(uint32_t address, uint8_t* data, size_t length);
error_t flashDriverRead(uint32_t address, uint8_t* data, size_t length);
error_t flashDriverSwapBanks(void);

///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////

/**
 * @brief Flash Information
 **/

const FlashInfo flashDriverInfo =
{
   FLASH_DRIVER_VERSION,
   STM32F412_NAME,
   FLASH_TYPE_INTERNAL,
   //FLASH_CLASS_FLASH,
   STM32F412_ADDR,
   STM32F412_SIZE,
   STM32F412_WRITE_SIZE,
   STM32F412_READ_SIZE,
   0,
   0,
   0,
   0,
   0
};

/**
 * @brief Flash Driver
 **/

const FlashDriver flashDriver =
{
   flashDriverInit,
   flashDriverGetInfo,
   flashDriverGetStatus,
   flashDriverWrite,
   flashDriverRead,
   flashDriverSwapBanks
};


/**
 * @brief Initialize Flash.
 * @return Error code
 **/

error_t flashDriverInit(void)
{
   //Return status code
   return ERROR_NOT_IMPLEMENTED;
}


/**
 * @brief Get Flash information.
 * @param[in,out] info Pointeur to the Flash information structure to be returned
 * @return Error code
 **/

error_t flashDriverGetInfo(const FlashInfo *info)
{
   //Return status code
   return ERROR_NOT_IMPLEMENTED;
}


/**
 * @brief Get Flash status.
 * @param[in,out] status Pointeur to the Flash status to be returned
 * @return Error code
 **/

error_t flashDriverGetStatus(FlashStatus *status)
{
   //Return status code
   return ERROR_NOT_IMPLEMENTED;
}


/**
 * @brief Write data in Flash at the given address.
 * @param[in] address Address in Flash to write to
 * @param[in] data Pointeur to the data to write
 * @param[in] length Number of data bytes to write in
 * @return Error code
 **/

error_t flashDriverWrite(uint32_t address, uint8_t* data, size_t length)
{
   //Return status code
   return ERROR_NOT_IMPLEMENTED;
}


/**
 * @brief Read data from Flash at the given address.
 * @param[in] address Address in Flash to read from
 * @param[in] data Buffer to store read data
 * @param[in] length Number of data bytes to read out
 * @return Error code
 **/

error_t flashDriverRead(uint32_t address, uint8_t* data, size_t length)
{
   //Return status code
   return ERROR_NOT_IMPLEMENTED;
}


/**
 * @brief Performs a Flash bank swap according to the current bank ID.
 * If current Flash bank ID match the 1st bank then it will swap on the 2nd Flash bank.
 * If current Flash bank ID match the 2nd bank then it will swap on the 1st Flash bank.
 * @return Error code
 **/

error_t flashDriverSwapBanks(void)
{
   //Return status code
   return ERROR_NOT_IMPLEMENTED;
}


///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
