/**
 * @file memory_driver_template.h
 * @brief CycloneBOOT Memory Driver Template
 *
 * @section License
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * Copyright (C) 2010-2022 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneBOOT Open.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.0.2
 **/

#ifndef _FLASH_DRIVER_TEMPLATE_H
#define _FLASH_DRIVER_TEMPLATE_H

//Dependencies
#include <stdlib.h>
#include <stdint.h>
#include "error.h"

//FLASH name
#define FLASH_NAME "FLASH Internal Flash"
//FLASH start addr
#define FLASH_ADDR 0x08000000
//FLASH size
#define FLASH_SIZE 0x100000
//FLASH write size
#define FLASH_WRITE_SIZE 0x04 //4-bytes word
//FLASH read size
#define FLASH_READ_SIZE 0x04 //4-bytes word

//FLASH sectors number
#define FLASH_SECTORS_NUMBER 12

//FLASH Sector start address list
#define FLASH_SECTOR_0_ADDR   0x08000000 //Base address of Sector 0,  End address at 0x08003FFF, 16 Kbytes   | 16 Kbytes
#define FLASH_SECTOR_1_ADDR   0x08004000 //Base address of Sector 1,  End address at 0x08007FFF, 16 Kbytes   | 32 Kbytes
#define FLASH_SECTOR_2_ADDR   0x08008000 //Base address of Sector 2,  End address at 0x0800BFFF, 16 Kbytes   | 48 Kbytes
#define FLASH_SECTOR_3_ADDR   0x0800C000 //Base address of Sector 3,  End address at 0x0800FFFF, 16 Kbytes   | 64 Kbytes
#define FLASH_SECTOR_4_ADDR   0x08010000 //Base address of Sector 4,  End address at 0x0801FFFF, 64 Kbytes   | 128 Kbytes
#define FLASH_SECTOR_5_ADDR   0x08020000 //Base address of Sector 5,  End address at 0x0803FFFF, 128 Kbytes  | 256 Kbytes
#define FLASH_SECTOR_6_ADDR   0x08040000 //Base address of Sector 6,  End address at 0x0805FFFF, 128 Kbytes  | 384 Kbytes
#define FLASH_SECTOR_7_ADDR   0x08060000 //Base address of Sector 7,  End address at 0x0807FFFF, 128 Kbytes  | 512 Kbytes
#define FLASH_SECTOR_8_ADDR   0x08080000 //Base address of Sector 8,  End address at 0x0809FFFF, 128 Kbytes  | 640 Kbytes
#define FLASH_SECTOR_9_ADDR   0x080A0000 //Base address of Sector 9,  End address at 0x080BFFFF, 128 Kbytes  | 768 Kbytes
#define FLASH_SECTOR_10_ADDR  0x080C0000 //Base address of Sector 10, End address at 0x080DFFFF, 128 Kbytes  | 896 Kbytes
#define FLASH_SECTOR_11_ADDR  0x080E0000 //Base address of Sector 11, End address at 0x080FFFFF, 128 Kbytes  | 1024 Kbytes

//FLASH Sectors size list
#define FLASH_SECTOR_0_SIZE   0x4000
#define FLASH_SECTOR_1_SIZE   0x4000
#define FLASH_SECTOR_2_SIZE   0x4000
#define FLASH_SECTOR_3_SIZE   0x4000
#define FLASH_SECTOR_4_SIZE   0x10000
#define FLASH_SECTOR_5_SIZE   0x20000
#define FLASH_SECTOR_6_SIZE   0x20000
#define FLASH_SECTOR_7_SIZE   0x20000
#define FLASH_SECTOR_8_SIZE   0x20000
#define FLASH_SECTOR_9_SIZE   0x20000
#define FLASH_SECTOR_10_SIZE  0x20000
#define FLASH_SECTOR_11_SIZE  0x20000

#endif //!_FLASH_DRIVER_TEMPLATE_H
