## Getting started with http_server_iap_dual_bank_demo

This demonstration project provided for the same54_xplained_pro contains a HTTP server and CycloneBOOT IAP middleware. The HTTP server will manage the recepetion of the update image. The CycloneBOOT IAP middleware will manage the processing of the image fetched by the HTTP server.

This demo makes use of the MCU flash dual bank functionnality. One bank holds the current application firmware while the other bank serve to store the new application firmware. This new application firmware comes from an update image. If the update process is successful (image is valid) then a swap between the two flash banks will be performed to boot to the new firmware.

It contains several update scenarios: 

- scenario 1 : plaintext firmware + integrity (CRC32)
- scenario 2 : cipher firmware + authentication (AES-CBC + HMAC-MD5)
- scenario 3 : cipher firmware + signature (AES-CBC + RSA-SHA256)

For demo purpose, the background color of the update web page and the displayed version of the application can be changed at compilation. For this you need to edit several macros in the file `version.h` in `same54_xplained_pro\http_server_iap_dual_bank_demo\src` directory. 

Here is an example if you want to generate an application firmware with a `red` background web page and the version `v2.5.1`:

```c
//Version string
#define APP_VERSION_STRING "2.5.1"
//Major version
#define APP_MAJOR_VERSION 2
//Minor version
#define APP_MINOR_VERSION 5
//Revision number
#define APP_REV_NUMBER 1
//Version color
#define APP_VERSION_COLOR "#FF0000" // RED hex color code
```

> Note: Per default the version is `v1.0.0` and the color is yellow (`#FFE082`)

### Step #0 : Prerequisites 

  - Download and install J-Link Software and Documentation Pack using
version 7.22 to support EDBG/CMSIS-DAP atmel on-board probe:
https://www.segger.com/downloads/jlink/JLink_Windows_V722.exe.
Make sure to add the JLink.exe in to your PATH.

### Step #1 : Board configuration

In this step, we will configure the same54_xplained_pro MCU to accept our project(s). Especially the MCU will be configured to run in dual bank mode (dual flash bank).

Plug the same54_xplained_pro to your computer.

**Manual method**: 

Run the following commands (making sure JLink.exe is in your PATH):

- Check on which bank the board is currently running by reading the NVMCTRL STATUS register (0x41004012) with this command : `JLink.exe -device ATSAME54P20 -if SWD -speed 4000 -autoconnect 1 -CommanderScript ./jlink/same54_read_nvmctrl_reg.jlink`
- The result should be similar to `0x41004012 = 11`. If the bit AFIRST (0x10) is set it means the board is already running on the first bank
- Else we need to swap the banks to start on the first bank using this command : `JLink.exe -device ATSAME54P20 -if SWD -speed 4000 -autoconnect 1 -CommanderScript ./jlink/same54_swap_flash_bank.jlink`

**Using the provided script**:

1. Navigate to `same54_xplained_pro/http_server_iap_dual_bank_demo/scripts` directory.
2. Run the `configure_dual_bank_mode.bat` script.
3. Your board is now ready.

### Step #2 : Generate demo firmware binaries

1. Open the http_server_iap_dual_bank_demo project : `same54_xplained_pro/http_server_iap_dual_bank_demo/keil/http_server_iap_dual_bank_demo.uvprojx`
2. Depending the choosen scenario, select the corresponding compilation profile. It can be one of these profile:
    - `scenario_1_simple_app_and_integrity`
    - `scenario_2_cipher_app_and_authentication`
    - `scenario_3_cipher_app_and_signature`
3. Clean then Build or Recompile the project
4. You should see this binary file `http_server_iap_dual_bank_demo.bin` in `same54_xplained_pro\http_server_iap_dual_bank_demo` directory

> **Tips:** You can change the version and the backgroud web page color of the demo application before compilation, as explained at the begining of this readme.

> Note: 
> - The scenario choosed for the compilation will reflect the type of image that CycloneBOOT IAP middleware will be able to manage.
> - If you want to change the scenario you MUST recompile the demo selecting the corresponding compilation profile  

### Step #3 : Load initial firmware in to flash

Once the application firmware generated you need to load it in to the first flash bank at address `0x00000000`.

You can perform this step either manually or by running the provided script.

**Manual Method** :

Several options are available:
- Use you favorite IDE to load the firmware generated in *Step #2* (for ex Keil)
- Or use J-Link with this command : `JLink.exe -device ATSAME54P20 -if SWD -speed 4000 -autoconnect 1 -CommanderScript ./jlink/same54_load_http_server_iap_dual_bank_demo.jlink`

**Using the provided script** :

Run `load_http_server_iap_dual_bank_demo.bat` in `../scripts` directory.

> **Important**: Make SURE that the MCU is running on the first flash bank before to load the firmware binary. If it is not the case then configure again the board as explained in *Step #1*.

### Step #4 : Generate demo firmware image updates

This step will transform the binary generated (at *Step #3*) in to an image file recognizable by CycloneBOOT. Regarding the choosen scenario used to build the current running firmware, the application will be expecting an update image generated for the same scenario.

Have a look to the function `httpServerRequestCallback()` in the `same54_xplained_pro\http_server_iap_single_bank_demo\src\http_server_callbacks.c` file to know which settings has been used to configure CycloneBOOT IAP in the demo application. These settings MUST match the options specified to generate the update image in regards to the choosen scenario.

You can perform these steps either manually or by running the provided script. 

**Manual Method** : 

From within the demo project directory, execute the following command for:
- Scenario 1: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe -input http_server_iap_dual_bank_demo.bin -output http_server_iap_dual_bank_demo_image_scenario_1.img -fv X.X.X`
- Scenario 2: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe -input http_server_iap_dual_bank_demo.bin -output http_server_iap_dual_bank_demo_image_scenario_2.img -fv X.X.X -ek aa3ff7d43cc015682c7dfd00de9379e7 -a hmac-md5 -ak 107b8d4bf62d1c9e26968e8ff51a74df`
- Scenario 3: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe -input http_server_iap_dual_bank_demo.bin -output http_server_iap_dual_bank_demo_image_scenario_3.img -fv X.X.X -ek aa3ff7d43cc015682c7dfd00de9379e7 -s rsa-sha256 -sk ../../http_server_iap_dual_bank_demo/resources/keys/rsa_private_key.pem`


**Using the provided script** :

Run `generate_http_server_iap_dual_bank_images.bat` in `../scripts` directory

- It will produce 3 images from the http_server_iap_dual_bank_demo.bin` binary file, one for each scenario:
    - http_server_iap_dual_bank_demo_image_scenario_1.img
    - http_server_iap_dual_bank_demo_image_scenario_2.img
    - http_server_iap_dual_bank_demo_image_scenario_3.img

Those images are generated in `../scripts` directory.

> Note: The *`-fv X.X.X`* command line option serves to indicate the version of the firmware application binary. You are free to specify another version.

### Step #5 : Test the Demo

**Note: Remember that the demo expects a specific scenario that has been chosen and the update image MUST also match that scenario.**

1. If not already done configure the board in dual bank mode as explained in *Step #1* (only needed for MCU that support dual bank flash), else skip this step.
2. If not already done compile the demo for the choosen scenario as explained in *Step #2*, else skip this step.
3. Load the demo firmware binary into flash at `0x00000000` as explained in *Step #3*.
4. Generate firmware update image as explained in *Step #4* in regards of the choosen scenario.
5. Open your favorite serial console (115200 bauds). 
6. Click on the reset button to restart the demo.
7. Get the IP address of the board from the serial console output.
8. Open a web browser and then navigate to the IP address of the board.
9. You should be able to see an orange update web page.
10. Click on `myFile` and select the `http_server_iap_dual_bank_demo_image_scenario_X.img` according the scenario.
11. Click on `Upload` to upload the image on to the server.
    If the update process is OK then the board will automatically reboot.
12. You shoud get an update web page reflecting the color chosen for the new version.
13. You can reproduce the step *10.* to *13.* by adapting the image file.

> **Tips:** You can also redo step *2.* followed by step *4.* to change the version and the background web page color of the application. This way you will be able to see the background web color and displayed application version change at each update (step *10.* to *13.*).  

> Note: If you want to test another scenario restart from step *1.*